@@ -34,17 +34,21 @@ class Abstract_SAS(saspy.SASsession):
                        sasobjsp_port,
                        java='/usr/bin/java',
                        **kwargs):
+        logging.debug('Initializing Abstrac sas class')
         self.sasobjsp_host = sasobjsp_host
         self.sasobjsp_port = sasobjsp_port
         self.sasobjsp_user = sasobjsp_user
         self.sasobjsp_pass = sasobjsp_pass
         self.java = java
+        self.connected = False
+        logging.debug('Generating saspy conn file')
         self.saspy_conn = create_saspyconn(sasobjsp_host=self.sasobjsp_host,
                                            sasobjsp_port=self.sasobjsp_port,
                                            java=self.java)
-
-        self.connected = False
-        super(Abstract_SAS, self).__init__(cfgfile=self.saspy_conn.name, omruser=self.sasobjsp_user,
+        logging.debug(f'Generated saspy conn file {self.saspy_conn.name}')
+        super(Abstract_SAS, self).__init__(cfgfile=self.saspy_conn.name,
+                                           cfgname='sasconnection',
+                                           omruser=self.sasobjsp_user,
                                            omrpw=self.sasobjsp_pass)
 
     # def connect(self):
