@@ -7,4 +7,7 @@ class SASMA(Abstract_SAS):
                        sasobjsp_host='vs246.imb.ru',
                        sasobjsp_port='8591',  **kwargs):
         self.platform = 'SASMA'
-        super(Abstract_SAS, self).__init__(sasobjsp_host, sasobjsp_port, sasobjsp_user, sasobjsp_pass)
\ No newline at end of file
+        super(Abstract_SAS, self).__init__(sasobjsp_host=sasobjsp_host,
+                                           sasobjsp_port=sasobjsp_port,
+                                           sasobjsp_user=sasobjsp_user,
+                                           sasobjsp_pass=sasobjsp_pass)
\ No newline at end of file
